@@ -1,8 +1,8 @@
 EOF2field <- function(eof,anomalies=FALSE) {
   x <-t(eof$EOF) %*% diag(eof$W) %*% t(eof$PC); x <- t(x)
   dim(x) <- eof$size
-  clim <- t(matrix(eof$clim,eof$size[3],eof$size[2]))
-  if (!anomalies) { 
+  if ((!anomalies) & !is.null(eof$clim)) { 
+    clim <- t(matrix(eof$clim,eof$size[3],eof$size[2]))
     for (i in 1:eof$size[1]) x[i,,] <- x[i,,] + clim
   }
   retrieve.nc  <- list(dat=x,lon=eof$lon,lat=eof$lat,tim=eof$tim,lev=NULL,
